summaryrefslogtreecommitdiff
path: root/riscos/gui/url_bar.h
diff options
context:
space:
mode:
Diffstat (limited to 'riscos/gui/url_bar.h')
-rw-r--r--riscos/gui/url_bar.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/riscos/gui/url_bar.h b/riscos/gui/url_bar.h
index 0f41a4b01..8e8d291ac 100644
--- a/riscos/gui/url_bar.h
+++ b/riscos/gui/url_bar.h
@@ -305,15 +305,15 @@ bool ro_gui_url_bar_set_site_favicon(struct url_bar *url_bar,
/**
* Set the favicon to a RISC OS filetype sprite based on the type of the
- * supplied content.
+ * content within the supplied window.
*
* \param *url_bar The URL Bar to update the favicon on.
* \param *h The content to use.
* \return true if successful; else false.
*/
bool ro_gui_url_bar_set_content_favicon(struct url_bar *url_bar,
- struct hlcache_handle *h);
+ struct gui_window *g);
/**
@@ -305,15 +305,15 @@ bool ro_gui_url_bar_set_site_favicon(struct url_bar *url_bar,
*
* \param *url_bar The URL Bar to update the favicon on.
- * \param *h The content to use.
+ * \param *g The window with the content to use.
* \return true if successful; else false.
*/